<?php

namespace Argus\Discord;

class Avatars {


    static function init () {

        if (get_option('argusDiscordReplaceWPAvatars')) {
            add_filter('get_avatar', ['Argus\Discord\Avatars', 'replaceWPAvatars'], 100, 3);
        }

        if (get_option('argusDiscordReplaceBuddypressAvatars')) {
            if (!is_admin()) add_filter('bp_core_fetch_avatar_no_grav', '__return_true');
            add_filter('bp_core_fetch_avatar', ['Argus\Discord\Avatars', 'replaceBuddyPressAvatars'], 100, 2);
            add_filter('bp_core_default_avatar', ['Argus\Discord\Avatars', 'replaceBuddyPressDefaultAvatars'], 100, 2);
            add_filter('bp_core_fetch_avatar_url', ['Argus\Discord\Avatars', 'replaceBuddyPressDefaultAvatarURLs'], 999999, 2);
        }
    }


    static function replaceBuddyPressAvatars ($avatar, $params) {
        if (!isset($params['object']) || $params['object'] != 'user') return $avatar;
        $discordID = get_user_meta($params['item_id'], 'dwpp-discord-id', true);
        return self::replaceAvatar($avatar, $discordID, $params['width']);
    }


    static function replaceBuddyPressDefaultAvatars ($avatar, $params) {
        if (!isset($params['object']) || $params['object'] != 'user') return $avatar;
        return self::replaceAvatar($avatar, 0, $params['width']);
    }


    static function replaceBuddyPressDefaultAvatarURLs ($avatar, $params) {
        if (!isset($params['object']) || $params['object'] != 'user') return $avatar;
        if (is_admin() && get_current_screen() && isset(get_current_screen()->base) && get_current_screen()->base == 'options-discussion') {
            return $avatar;
        }

        $discordID = get_user_meta($params['item_id'], 'dwpp-discord-id', true);
        $avatar    = Data::getAvatarLinkFromAuthorizedUsers($discordID, $params['width'], false);

        if (!$avatar) return self::getDefaultAvatarUrl($params['width']);
        return $avatar;
    }


    static function replaceWPAvatars ($avatar, $requestedUser, $size) {
        if (is_admin() && strpos($avatar, 'avatar-default') !== false && get_current_screen() && isset(get_current_screen()->base) && get_current_screen()->base == 'options-discussion') {
            return $avatar;
        }

        $user = false;

        // Retrieving user object
        if (is_numeric($requestedUser)) {
            $id   = (int)$requestedUser;
            $user = get_user_by('id', $id);

        } elseif (is_object($requestedUser)) {
            if (!empty($requestedUser->user_id)) {
                $id   = (int)$requestedUser->user_id;
                $user = get_user_by('id', $id);
            }

        } elseif (filter_var($requestedUser, FILTER_VALIDATE_EMAIL)) {
            $user = get_user_by('email', $requestedUser);
        }


        // Replacing image
        if ($user && is_object($user)) {
            $discordID = get_user_meta($user->data->ID, 'dwpp-discord-id', true);
            $avatar    = self::replaceAvatar($avatar, $discordID, $size);
        }

        return $avatar;
    }


    private static function replaceAvatar ($avatar, $discordID, $size) {
        $discordAvatar   = Data::getAvatarLinkFromAuthorizedUsers($discordID, $size, false);
        $discordAvatar2x = Data::getAvatarLinkFromAuthorizedUsers($discordID, ($size * 2), false);
        if (!$discordAvatar) $discordAvatar = self::getDefaultAvatarUrl($size);
        if (!$discordAvatar2x) $discordAvatar2x = self::getDefaultAvatarUrl(($size * 2));

        $avatar = preg_replace('/src=\"([^\"\']*)\"|src=\'([^\"\']*)\'/', 'src="' . $discordAvatar . '"', $avatar);
        return preg_replace('/srcset=\"([^\"\']*)\"|srcset=\'([^\"\']*)\'/', 'srcset="' . $discordAvatar2x . ' 2x"', $avatar);
    }


    static function getDefaultAvatarUrl ($size):string {
        $size   = [$size, $size];
        $avatar = get_option('argusDiscordReplaceDefaultAvatar');
        $url    = wp_get_attachment_image_url($avatar, $size);
        if ($url) return $url;
        return Data::getDiscordIconURL('accent');
    }

}
