<?php

namespace Argus\Discord;

class Cron {


    static function init () {

        add_filter('cron_schedules', function($schedules) {
            $schedules['weekly'] = [
                'interval' => WEEK_IN_SECONDS,
                'display'  => esc_html__("Once Weekly", 'argus-wordpress-plugin')
            ];
            return $schedules;
        });

        add_filter('cron_schedules', function($schedules) {
            $schedules['four_days'] = [
                'interval' => DAY_IN_SECONDS * 4,
                'display'  => esc_html__("Once in 4 Days", 'argus-wordpress-plugin')
            ];
            return $schedules;
        });


        add_action('argus_discord_data_fetch_profile', function() {
            Data::fetchAuthorizedProfile();
        });

        add_action('argus_discord_data_fetch_app', function() {
            Data::fetchAuthorizedApp();
        });

        add_action('argus_discord_data_fetch_guild', function() {
            Data::fetchGuild();
        });

        add_action('argus_discord_data_fetch_joined_members', function() {
            Data::fetchMembers();
        });

        add_action('argus_discord_data_fetch_guild_roles', function() {
            Data::fetchAllRoles();
        });

        add_action('argus_discord_data_fetch_channels', function() {
            Data::fetchAllChannels();
        });

        add_action('argus_discord_data_fetch_messages', function() {
            Data::fetchMessagesFromAllChannels();
        });

        add_action('argus_discord_data_fetch_pinned_messages', function() {
            Data::fetchPinnedMessagesFromAllChannels();
        });

        add_action('argus_discord_data_synchronize_all_roles', function() {
            RolesSync::syncAllUsersRoles();
        });

        add_action('argus_discord_oauth2_token_refresh', function() {
            Data::refreshBearerToken();
        });
    }


    static function schedule () {
        $cronEvents = [
            ['argus_discord_data_fetch_profile', time() + HOUR_IN_SECONDS, 'weekly'],
            ['argus_discord_data_fetch_app', time() + HOUR_IN_SECONDS, 'weekly'],
            ['argus_discord_data_fetch_guild', time() + HOUR_IN_SECONDS, 'weekly'],
            ['argus_discord_data_fetch_joined_members', time() + DAY_IN_SECONDS, 'daily'],
            ['argus_discord_data_fetch_guild_roles', time() + WEEK_IN_SECONDS, 'weekly'],
            ['argus_discord_data_fetch_channels', time() + DAY_IN_SECONDS, 'daily'],
            ['argus_discord_data_fetch_messages', time() + HOUR_IN_SECONDS, 'hourly'],
            ['argus_discord_data_fetch_pinned_messages', time() + HOUR_IN_SECONDS, 'twicedaily'],
            ['argus_discord_data_synchronize_all_roles', time() + DAY_IN_SECONDS, 'four_days'],
            ['argus_discord_oauth2_token_refresh', time() + WEEK_IN_SECONDS, 'four_days'],
        ];

        foreach ($cronEvents as $event) {
            if (!wp_next_scheduled($event[0])) {
                wp_schedule_event($event[1], $event[2], $event[0]);
            }
        }
    }


    static function unschedule () {
        $cronEventsHooks = [
            'argus_discord_data_fetch_profile',
            'argus_discord_data_fetch_app',
            'argus_discord_data_fetch_guild',
            'argus_discord_data_fetch_joined_members',
            'argus_discord_data_fetch_guild_roles',
            'argus_discord_data_fetch_channels',
            'argus_discord_data_fetch_messages',
            'argus_discord_data_fetch_pinned_messages',
            'argus_discord_data_fetch_invite_link',
            'argus_discord_data_synchronize_all_roles',
        ];

        foreach ($cronEventsHooks as $hook) wp_clear_scheduled_hook($hook);
    }

}
