<?php

namespace Argus\Discord;

use Elementor\Plugin;

final class Elementor {

    private static ?Elementor $_instance = null;


    public static function instance ():?Elementor {
        if (is_null(self::$_instance)) self::$_instance = new self();
        return self::$_instance;
    }


    function __construct () {
        add_action('elementor/widgets/register', ['Argus\Discord\Elementor', 'register_widgets'], 99);
        add_action('elementor/frontend/after_enqueue_styles', ['Argus\Discord\Elementor', 'widget_styles']);
    }


    static function register_widgets () {
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/default-widget/ElementorWidgetDefault.php';
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/members-count/ElementorWidgetMembersCount.php';
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/invite-link/ElementorWidgetInviteLink.php';
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/authorization/ElementorWidgetAuthorization.php';
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/sharing/ElementorWidgetSharing.php';
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/connect-profile/ElementorWidgetConnectProfile.php';
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/synchronization/ElementorWidgetSynchronization.php';
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/invite-banner/ElementorWidgetInviteBanner.php';
        include_once ARGUS_DISCORD_PLUGIN_PATH . 'widgets/chat/ElementorWidgetChat.php';

        Plugin::instance()->widgets_manager->register(new ElementorWidgetDefault());
        Plugin::instance()->widgets_manager->register(new ElementorWidgetMembersCount());
        Plugin::instance()->widgets_manager->register(new ElementorWidgetInviteLink());
        Plugin::instance()->widgets_manager->register(new ElementorWidgetAuthorization());
        Plugin::instance()->widgets_manager->register(new ElementorWidgetSharing());
        Plugin::instance()->widgets_manager->register(new ElementorWidgetConnectProfile());
        Plugin::instance()->widgets_manager->register(new ElementorWidgetSynchronization());
        Plugin::instance()->widgets_manager->register(new ElementorWidgetInviteBanner());
        Plugin::instance()->widgets_manager->register(new ElementorWidgetChat());
    }


    static function widget_styles () {
        wp_enqueue_style('argus-discord-front-end-styles');
    }


    static function register_category () {
        add_action('elementor/elements/categories_registered', function($elementsManager) {
            $elementsManager->add_category('argus-discord-category', [
                'title' => __("Discord", 'argus-wordpress-plugin'),
                'icon'  => 'fab fa-discord',
            ]);
        });
    }


    static function connect_editor_assets () {
        wp_enqueue_style('argus-discord-elementor-icons', ARGUS_DISCORD_PLUGIN_URL . 'views/styles/elementor-icons.css', [], ARGUS_PLUGIN_VERSION);
    }

}
