<?php

namespace Argus\Discord;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;


class ElementorWidgetChat extends Widget_Base {


    function get_name ():string {
        return 'argus_discord_chat_widget';
    }


    function get_title ():string {
        return __("Discord Chat", 'argus-wordpress-plugin');
    }


    function get_icon ():string {
        return 'argus-discord-icon-chat';
    }


    function get_categories ():array {
        return ['argus-discord-category'];
    }


    function get_style_depends ():array {
        return ['argus-discord-front-end-styles'];
    }


    function get_script_depends ():array {
        return ['jQuery'];
    }


    protected function register_controls () {
        $channel_objects = Data::getAllChannelsList();

        $channels = [];

        foreach ($channel_objects as $channel) {
            $channels[ $channel->id ] = $channel->name;
        }
        $channels[0] = __("Do not invite", 'argus-wordpress-plugin');

        $this->start_controls_section('section_content', [
            'label' => __("Main", 'argus-wordpress-plugin'),
            'tab'   => Controls_Manager::TAB_CONTENT,
        ]);

        $this->add_control('title', [
            'label'       => 'Title',
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __("Title", 'argus-wordpress-plugin'),
            'default'     => __("Discord Chat", 'argus-wordpress-plugin'),
        ]);

        $this->add_control('channel', [
            'label'   => __("Get messages from", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => count($channel_objects) ? $channel_objects[0]->id : '',
            'options' => $channels,
        ]);

        $this->add_control('pinnedMessages', [
            'label'   => __("Only pinned messages", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => 'noFilter',
            'options' => [
                'noFilter'   => __("Do not filter", 'argus-wordpress-plugin'),
                'onlyPinned' => __("Only pinned", 'argus-wordpress-plugin'),
            ],
        ]);

        $this->add_control('tenorMessages', [
            'label'   => __("Tenor messages", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => 'video',
            'options' => [
                'video' => __("Show video", 'argus-wordpress-plugin'),
                'link'  => __("Show link", 'argus-wordpress-plugin'),
            ],
        ]);

        $this->add_control('imageMessages', [
            'label'   => __("Images in messages", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => 'image',
            'options' => [
                'image' => __("Show image", 'argus-wordpress-plugin'),
                'link'  => __("Show link", 'argus-wordpress-plugin'),
            ],
        ]);

        $this->add_control('customEmojiMessages', [
            'label'   => __("Custom emoji", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => 'image',
            'options' => [
                'image' => __("Show image", 'argus-wordpress-plugin'),
                'hide'  => __("Hide", 'argus-wordpress-plugin'),
            ],
        ]);

        $this->add_control('linkMessages', [
            'label'       => __("Links", 'argus-wordpress-plugin'),
            'description' => __("Display images and Tenor as text links if they are disabled", 'argus-wordpress-plugin'),
            'type'        => Controls_Manager::SELECT,
            'default'     => 'link',
            'options'     => [
                'link' => __("Display as text", 'argus-wordpress-plugin'),
                'hide' => __("Hide", 'argus-wordpress-plugin'),
            ],
        ]);

        $this->add_control('messages', [
            'label'       => __("Quantity", 'argus-wordpress-plugin'),
            'type'        => Controls_Manager::NUMBER,
            'placeholder' => '20',
            'min'         => 1,
            'max'         => 50,
            'default'     => 20,
        ]);

        $this->add_control('footerText', [
            'label'       => __("Footer text", 'argus-wordpress-plugin'),
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __("Hangout with people who get it", 'argus-wordpress-plugin'),
            'default'     => __("Hangout with people who get it", 'argus-wordpress-plugin'),
        ]);

        $this->add_control('link', [
            'label'   => __("Invite to channel", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => count($channel_objects) ? $channel_objects[0]->id : '',
            'options' => $channels,
        ]);

        $this->end_controls_section();

        $this->start_controls_section('section_style', [
            'label' => __("Settings", 'argus-wordpress-plugin'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_control('color', [
            'label'   => __("Colors", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => 'argus_widget_theme_light',
            'options' => [
                'argus-discord-widget--theme-light' => __("Light Style", 'argus-wordpress-plugin'),
                'argus-discord-widget--theme-dark'  => __("Dark Style", 'argus-wordpress-plugin'),
            ],
        ]);

        $this->add_control('height', [
            'label'       => __("Height", 'argus-wordpress-plugin'),
            'type'        => Controls_Manager::NUMBER,
            'placeholder' => '350',
            'min'         => 300,
            'default'     => 350,
        ]);

        $this->end_controls_section();

    }


    protected function render () {
        $instance = $this->get_settings_for_display();

        $messages = Data::getAllMessagesData($instance['channel'], $instance['messages'], ($instance['pinnedMessages'] == 'onlyPinned'));
        $filter   = [
            'customEmoji' => $instance['customEmojiMessages'],
            'images'      => $instance['imageMessages'],
            'links'       => $instance['linkMessages'],
            'tenor'       => $instance['tenorMessages']
        ];
        $invite   = $instance['link'] ? Data::getInviteLink($instance['link']) : false;

        require ARGUS_DISCORD_PLUGIN_PATH . 'widgets/caht/chat.phtml';
    }


    protected function content_template () {
        ?>
        <div class="argus-discord-widget argus-discord-widget-chat {{{ settings.color }}}">

            <# if ( settings.title ) { #>
            <div class="argus-discord-widget__header">
                <img class="argus-discord-widget__logo"
                     src="<?php echo Data::getDiscordIconURL(); ?>"
                     alt="<?php _e("Discord Icon", 'argus-wordpress-plugin'); ?>"
                     height="34">
                <span class="argus-discord-widget__title">
                    {{{ settings.title }}}
                </span>
            </div>
            <# } #>

            <div class="argus-discord-widget__body" style="max-height: {{{ settings.height }}}px;">

                <# if (sessionStorage.getItem('argus_discord_messages_requested') !== '1') { sessionStorage.setItem('argus_discord_messages_requested', '1' ); sessionStorage.setItem('argus_discord_messages', JSON.stringify([]) ); jQuery.get(ajaxurl, { action: 'argusDiscordGetInterpretedMessages', channel: settings.channel, quantity: settings.messages, customEmoji: settings.customEmojiMessages === 'image', images: settings.imageMessages === 'image', links: settings.linkMessages === 'link', tenor: settings.tenorMessages === 'video', pinned: settings.pinnedMessages === 'onlyPinned' }) .done(function (data) { sessionStorage.setItem('argus_discord_messages', JSON.stringify(data.data.message) ); let jQueryControls = jQuery( ".elementor-control-type-select select" ); if (jQueryControls.length) { jQuery(jQueryControls[0]).trigger( "change" ); } sessionStorage.setItem('argus_discord_messages_requested', '0' ); }); }

                let messages = JSON.parse( sessionStorage.getItem('argus_discord_messages') ); if ( !Array.isArray(messages) ) { messages = []; } #>

                <# if ( messages.length ) { #>
                <ul class="argus-discord-widget__chat">
                    <# _.each( messages, function( message ) { #> <# if (message.fetched.type === 0 && message.content) { #>
                    <li>
                        <span class="argus-discord-widget__chat-avatar">
                            <img class="argus-discord-widget__avatar"
                                 src="{{{ message.avatar }}}"
                                 width="16"
                                 height="16"
                                 alt="{{{ message.name }}} avatar">
                        </span>
                        <span class="argus-discord-widget__chat-name">
                            {{{ message.name }}}
                        </span>
                        <span></span>
                        <span class="argus-discord-widget__chat-message">
                            {{{ message.content }}}
                        </span>
                    </li>
                    <# } #> <# }); #>
                </ul>

                <# } else { #>
                <?php _e("No messages found", 'argus-wordpress-plugin'); ?>
                <# } #>
            </div>

            <# if ( settings.link != 0 || settings.footerText ) { #>
            <div class="argus-discord-widget__footer">
                <div class="argus-discord-widget__footer-text">
                    {{{ settings.footerText }}}
                </div>
                <# if ( settings.link ) { #>
                <a href="{{{ settings.link }}}" class="argus-discord-widget__button" target="_blank">
                    <?php _e("Connect", 'argus-wordpress-plugin'); ?>
                </a>
                <# } #>
            </div>
            <# } #>

        </div>
        <?php
    }

}
