<?php

namespace Argus\Discord;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;


class ElementorWidgetInviteBanner extends Widget_Base {


    function get_name ():string {
        return 'argus_discord_invite_banner_widget';
    }


    function get_title ():string {
        return __("Discord Invite Banner", 'argus-wordpress-plugin');
    }


    function get_icon ():string {
        return 'argus-discord-icon-invite-banner';
    }


    function get_categories ():array {
        return ['argus-discord-category'];
    }


    function get_style_depends ():array {
        return ['argus-discord-front-end-styles'];
    }


    protected function register_controls () {
        $channel_objects = Data::getAllChannelsList();

        $channels = [];

        foreach ($channel_objects as $channel) {
            $channels[ $channel->id ] = $channel->name;
        }

        $this->start_controls_section('section_content', [
            'label' => __("Main", 'argus-wordpress-plugin'),
            'tab'   => Controls_Manager::TAB_CONTENT,
        ]);

        $this->add_control('channel', [
            'label'   => __("Invite to channel", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => count($channel_objects) ? $channel_objects[0]->id : '',
            'options' => $channels,
        ]);

        $this->add_control('text', [
            'label'   => __("Text", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::TEXT,
            'default' => __("Hangout with people who get it", 'argus-wordpress-plugin'),
        ]);

        $this->add_control('show_count', [
            'label'   => __("Display members count", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => 'show',
            'options' => [
                'show' => __("Show", 'argus-wordpress-plugin'),
                'hide' => __("Hide", 'argus-wordpress-plugin'),
            ],
        ]);

        $this->end_controls_section();
    }


    protected function render () {
        $settings = $this->get_settings_for_display();

        $invite = Data::getInviteLink($settings['channel']);
        if (!$invite) $invite = 'javascript:void(0)';
        $icon              = Data::getDiscordIconURL();
        $instance['title'] = $settings['text'];
        $membersCount      = $settings['show_count'] == 'show' ? Data::getData('Guild')->approximate_member_count : false;

        require ARGUS_DISCORD_PLUGIN_PATH . 'widgets/invite-banner/invite-banner.phtml';
    }


    protected function content_template () {
        $icon         = Data::getDiscordIconURL();
        $membersCount = Data::getData('Guild')->approximate_member_count;

        ?>
        <a href="javascript:void(0)" class="argus-discord-widget-banner argus-discord-widget-banner-invite-banner">
            <span class="argus-discord-widget-banner__row">
                <img class="argus-discord-widget__logo"
                     src="<?php echo $icon; ?>"
                     alt="<?php _e("Discord Icon", 'argus-wordpress-plugin'); ?>"
                     height="34">
                <span class="argus-discord-widget-banner__column">
                    <span class="argus-discord-widget__title">
                        {{{ settings.text }}}
                    </span>
                    <# if ( settings.show_count == 'show' ) { #>
                    <span>
                        <?php _e("Members count:", 'argus-wordpress-plugin'); ?>&nbsp;
                        <?php echo $membersCount; ?>
                    </span>
                    <# } #>
                </span>
            </span>
        </a>
        <?php
    }


}
