<?php

namespace Argus\Discord;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;


class ElementorWidgetSharing extends Widget_Base {


    function get_name ():string {
        return 'argus_discord_sharing_widget';
    }


    function get_title ():string {
        return __("Discord Sharing Button", 'argus-wordpress-plugin');
    }


    function get_icon ():string {
        return 'argus-discord-icon-share-button';
    }


    function get_categories ():array {
        return ['argus-discord-category'];
    }


    protected function register_controls () {

        $this->start_controls_section('section_content', [
            'label' => __("Main", 'argus-wordpress-plugin'),
            'tab'   => Controls_Manager::TAB_CONTENT,
        ]);

        $this->add_control('text', [
            'label'   => __("Button text", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::TEXT,
            'default' => __("Share on Discord", 'argus-wordpress-plugin'),
        ]);

        $this->end_controls_section();

        $this->start_controls_section('section_style', [
            'label' => __("Settings", 'argus-wordpress-plugin'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_control('style', [
            'label'   => __("Style", 'argus-wordpress-plugin'),
            'type'    => Controls_Manager::SELECT,
            'default' => 'no',
            'options' => [
                'no'      => __("None", 'argus-wordpress-plugin'),
                'default' => __("Default", 'argus-wordpress-plugin'),
            ],
        ]);

        $this->end_controls_section();
    }


    protected function render () {
        $settings = $this->get_settings_for_display();

        if ($settings['style'] != 'no') wp_enqueue_style('argus-discord-front-end-styles');

        $link = Data::getShareLink();

        if (isset($settings['style'])) {
            $class = 'argus__button--' . $settings['style'] . '-style';
        } else {
            $class = 'argus__button--no-style';
        }

        $text = $settings['text'] ?? __("Share on Discord", 'argus-wordpress-plugin');

        ?>
        <a class="argus__login <?php echo $class; ?>" href="<?php echo $link; ?>"><?php echo $text; ?></a>
        <?php
    }


    protected function content_template () {
        ?>
        <a class="argus__login argus__button--{{{ settings.style }}}-style" href="javascript:void(0)">
            {{{ settings.text ? settings.text : "<?php _e("Share on Discord", 'argus-wordpress-plugin'); ?>" }}}
        </a>
        <?php
    }


}
