<?php

namespace Argus\Steam;

use Argus\AdminSettingsAbstraction;


class AdminSettings extends AdminSettingsAbstraction {


    static function displayMainSettingsPage () {
        wp_enqueue_script('argus-steam-admin-panel-scripts', ARGUS_STEAM_PLUGIN_URL . 'controllers/AdminSettings.js', ['jquery', 'react', 'react-dom'], ARGUS_PLUGIN_VERSION, true);

        $translationsFile = ARGUS_STEAM_PLUGIN_PATH . '/languages/argus-steam-react-' . get_locale() . '.json';
        $registeredCPT    = get_post_types([], 'object');
        $dynamicColors    = self::buildDynamicAdminColors();

        ?>
        <script>
            var argusStateValues = {};

            <?php if ((int)get_option('argusActivateTranslations') && file_exists($translationsFile)) { ?>
            argusStateValues.translations = <?php echo file_get_contents($translationsFile); ?>;
            <?php } else { ?>
            argusStateValues.translations = false;
            <?php } ?>

            argusStateValues.colors = {
                accent: "<?php echo $dynamicColors[2]['bg']; ?>",
                text  : "<?php echo $dynamicColors[2]['text']; ?>"
            }

            argusStateValues.elementorError    = "<?php echo addslashes(self::checkElementorVersion()); ?>";
            argusStateValues.supportEmail      = "<?php echo ARGUS_SUPPORT_EMAIL; ?>";
            argusStateValues.supportExpireDate = "<?php echo self::buildSupportDateTemplate(); ?>";
            argusStateValues.documentationLink = "<?php echo ARGUS_DOC_LINK; ?>";

            argusStateValues.registeredCPT = [
                <?php foreach($registeredCPT as $cpt) {if ($cpt->name != 'revision' && $cpt->name != 'nav_menu_item') { ?>
                {
                    value: "<?php echo $cpt->name; ?>",
                    name : "<?php echo addslashes($cpt->label); ?>"
                },
                <?php }} ?>
            ];

            argusStateValues.settingsValues = {
                argusSteamCustomRedirects    : [
                    <?php $redirectArray = json_decode(get_option('argusSteamCustomRedirects')); ?>
                    <?php if ($redirectArray) {foreach($redirectArray as $id => $redirect) { ?>
                    {
                        id  : <?php echo $id; ?>,
                        name: "<?php echo $redirect->name; ?>",
                        url : "<?php echo $redirect->url; ?>"
                    },
                    <?php }} ?>
                    {
                        id  : <?php echo time(); ?>,
                        name: '',
                        url : ''
                    }],
                argusSteamModifyWPLoginForm  : <?php echo (int)get_option('argusSteamModifyWPLoginForm'); ?>,
                argusSteamStylingOAuthButtons: <?php echo (int)get_option('argusSteamStylingOAuthButtons'); ?>,
                argusSteamCommentsCPT        : "<?php echo get_option('argusSteamCommentsCPT'); ?>"
            };
        </script>

        <div id="argus-steam-admin-settings"></div>
        <?php
    }


    static function modifyProfilePage ($user) {
        $steamID = get_user_meta($user->ID, 'argusSteamID', true);
        wp_enqueue_script('argus-admin-helpers-scripts');
        include_once ARGUS_STEAM_PLUGIN_PATH . 'views/includes/profile-settings.phtml';
    }


    static function modifyPersonalProfilePage ($user) {
        $connected = false;
        $steamID   = get_user_meta($user->ID, 'argusSteamID', true);

        if ($steamID) $connected = true;
        $authorizationLink = Data::getAuthorizationLink('argus-connect-steam-profile-to-user');

        wp_enqueue_script('argus-admin-helpers-scripts');
        include_once ARGUS_STEAM_PLUGIN_PATH . 'views/includes/personal-profile-settings.phtml';
    }


    static function saveDataFromProfilePage ($userID) {
        if (!current_user_can('edit_user', $userID)) return false;
        $newID = '';
        if (intval($_POST['argusSteamID'])) $newID = wp_strip_all_tags($_POST['argusSteamID']);
        return update_user_meta($userID, 'argusSteamID', $newID);
    }

}
