<?php

namespace Argus\Steam;

if (!defined('ABSPATH')) exit;


// Checking if component is installed
if (in_array('steam', ARGUS_ACTIVE_COMPONENTS)) {

    // Defining constants
    define('Argus\Steam\ARGUS_STEAM_PLUGIN_PATH', ARGUS_PLUGIN_PATH . 'components/steam/');
    define('Argus\Steam\ARGUS_STEAM_PLUGIN_URL', ARGUS_PLUGIN_URL . 'components/steam/');

    // Loading models
    include_once ARGUS_STEAM_PLUGIN_PATH . 'libraries/LightOpenID.php';
    include_once ARGUS_STEAM_PLUGIN_PATH . 'models/Data.php';

    // Loading controllers
    include_once ARGUS_STEAM_PLUGIN_PATH . 'controllers/Activate.php';
    include_once ARGUS_STEAM_PLUGIN_PATH . 'controllers/Deactivate.php';
    include_once ARGUS_STEAM_PLUGIN_PATH . 'controllers/Cron.php';
    include_once ARGUS_STEAM_PLUGIN_PATH . 'controllers/Authorization.php';
    include_once ARGUS_STEAM_PLUGIN_PATH . 'controllers/AdminSettings.php';
    include_once ARGUS_STEAM_PLUGIN_PATH . 'controllers/Gutenberg.php';

    // Loading ajax hooks
    include_once ARGUS_STEAM_PLUGIN_PATH . 'controllers/ajax-hooks.php';


    // Registering front end styles
    add_action('wp_enqueue_scripts', function() {
        wp_register_style('argus-steam-front-end-styles', ARGUS_STEAM_PLUGIN_URL . 'views/styles/frontend.css', [], ARGUS_PLUGIN_VERSION);
    });

    // Loading widgets
    include_once ARGUS_STEAM_PLUGIN_PATH . 'widgets/authorization/authorization-shortcode.php';
    include_once ARGUS_STEAM_PLUGIN_PATH . 'widgets/authorization/authorization-gutenberg.php';


    // Registering gutenberg section
    Gutenberg::registerSection();

    // Registering elementor blocks
    if (ARGUS_ELEMENTOR_ACTIVE) {
        include_once ARGUS_STEAM_PLUGIN_PATH . 'controllers/Elementor.php';
        Elementor::instance();
        Elementor::register_category();
        add_action('elementor/editor/before_enqueue_scripts', ['Argus\Steam\Elementor', 'connect_editor_assets']);
    }


    // Initializing cron
    Cron::init();


    // Catching request to disconnect Steam profile
    if (isset($_GET['action']) && $_GET['action'] == 'argus-disconnect-steam-profile') {
        add_action('wp_loaded', ['Argus\Steam\Authorization', 'disconnectSteamProfileFromUser']);
    }

    // Catching steam API authorization response
    if (isset($_GET['state']) && $_GET['state'] == 'argus-auth-steam-go-last-page') {
        add_action('wp_loaded', function() {
            Authorization::authorizeOrRegisterUser();
        }, 1, 0);
    }
    if (isset($_GET['state']) && $_GET['state'] == 'argus-auth-steam-go-prev-page') {
        add_action('wp_loaded', function() {
            Authorization::authorizeOrRegisterUser('argusPrevPage');
        }, 1, 0);
    }
    if (isset($_GET['state']) && preg_match('/^argus-auth-steam-go-([0-9]+)-page$/', $_GET['state'])) {
        add_action('wp_loaded', function() {
            Authorization::authorizeOrRegisterUser($_GET['state']);
        }, 1, 0);
    }

    if (isset($_GET['state']) && $_GET['state'] == 'argus-connect-steam-profile-to-user') {
        add_action('wp_loaded', ['Argus\Steam\Authorization', 'connectProfileToUser']);
    }

    // Minifying default WP login form
    add_action('login_form', ['Argus\Steam\Authorization', 'modifyWPLoginForm'], 100, 0);


    // Modifying comment forms
    add_action('comment_form_top', ['Argus\Steam\Authorization', 'addCommentWithSteamButton'], 100, 0);


    // Admin panel actions
    if (is_admin()) {

        // Subscribing user profile actions
        add_action('edit_user_profile', ['Argus\Steam\AdminSettings', 'modifyProfilePage']);
        add_action('show_user_profile', ['Argus\Steam\AdminSettings', 'modifyPersonalProfilePage']);
        add_action('edit_user_profile_update', ['Argus\Steam\AdminSettings', 'saveDataFromProfilePage']);
        add_action('personal_options_update', ['Argus\Steam\AdminSettings', 'saveDataFromProfilePage']);

        // Registering admin panel controls
        add_action('admin_menu', function() {
            $page = add_options_page(__("Steam Plugin Settings", 'argus-wordpress-plugin'), __("Steam", 'argus-wordpress-plugin'), 'manage_options', 'argus-steam-plugin-settings', ['Argus\Steam\AdminSettings', 'displayMainSettingsPage']);

            add_action('load-' . $page, function() {
                wp_enqueue_media();
                wp_enqueue_style('argus-admin-panel-styles');
                wp_enqueue_script('argus-admin-helpers-scripts');
                wp_enqueue_script('argus-steam-admin-panel-scripts', ARGUS_STEAM_PLUGIN_URL . 'controllers/AdminSettings.js', ['jquery', 'react', 'react-dom'], ARGUS_PLUGIN_VERSION, true);
            });
        });

        // Additional help tabs
        global $pagenow;
        if ($pagenow == 'user-edit.php') {
            add_action('admin_head', function() {
                $currentScreen = get_current_screen();
                include_once ARGUS_STEAM_PLUGIN_PATH . 'views/includes/profile-help-tab.php';
                foreach ($tabs as $tab) $currentScreen->add_help_tab($tab);
            });
        }

        // Plugins manager page modifications
        add_filter('plugin_action_links_argus-wordpress-plugin', ['Argus\Steam\AdminSettings', 'modifyPluginsManagerPage']);

    }
}
